import * as webpack from 'webpack';
import { DynamicModuleMap } from '../../utils/dynamic-module-parser';
export type DynamicModuleImportLoaderOptions = {
    dynamicModuleMaps: Record<string, DynamicModuleMap>;
    resourceMetadata: {
        jsx: boolean;
    };
};
export type DynamicModuleImportLoader = webpack.LoaderDefinitionFunction<DynamicModuleImportLoaderOptions>;
/**
 * Internal webpack loader used to apply dynamic module import transformations.
 *
 * For example, the following import:
 * ```ts
 * import { Alert, AlertProps, Wizard } from '@patternfly/react-core';
 * ```
 * will be transformed into:
 * ```ts
 * import { Alert } from '@patternfly/react-core/dist/dynamic/components/Alert';
 * import { AlertProps } from '@patternfly/react-core/dist/dynamic/components/Alert';
 * import { Wizard } from '@patternfly/react-core/dist/dynamic/components/Wizard';
 * ```
 *
 * This loader requires the `typescript` package to be installed in the consuming project.
 *
 * @see https://webpack.js.org/contribute/writing-a-loader/
 */
declare const dynamicModuleImportLoader: DynamicModuleImportLoader;
export default dynamicModuleImportLoader;
